Derivative matrix
=================

Used in regularised inversion methods MFR and LAME. Various schemes for computation are used. Anisotropic derivatives can be computed using magnetics data.


Implementation
--------------

Convenience functions for computation return list of tuples holding a pair of sparse matrices.


